@@ -37,10 +37,10 @@ def build(src_path, dst_path):
         shutil.rmtree(dst_path)
 
     shutil.copytree(src_path, dst_path)
-    render(src_path, dst_path, data)
+    render(src_path, dst_path, data, [])
 
 
-def render(src_path, dst_path, data):
+def render(src_path, dst_path, data, loaders):
     local_data, module = get_data(dst_path, remove=True)
     data.update(local_data)
 
@@ -53,19 +53,29 @@ def render(src_path, dst_path, data):
         external_data, m = get_data(normalized, remove=False)
         data.update(external_data)
 
-    # TODO: support custom templates path
-    loader = jinja2.FileSystemLoader(searchpath=dst_path)
-    env = jinja2.Environment(loader=jinja2.ChoiceLoader([loader]))
+    if "templates" in local_data:
+        if data["templates"].startswith("/"):
+            normalized = data["templates"]
+        else:
+            normalized = os.path.join(src_path, data["templates"])
+
+        loaders.append(jinja2.FileSystemLoader(searchpath=normalized))
+
+    loaders.append(jinja2.FileSystemLoader(searchpath=dst_path))
+    env = jinja2.Environment(loader=jinja2.ChoiceLoader(loaders))
 
     for filename in os.listdir(dst_path):
-        # TODO: support generic paths
+        # TODO: support more generic handling of paths
         if "exclude" in data and filename in data["exclude"]:
             continue
 
+        if "templates" in data and filename in data["templates"]:
+            continue
+
         new_dst_path = os.path.join(dst_path, filename)
         if os.path.isdir(new_dst_path):
             new_src_path = os.path.join(src_path, filename)
-            render(new_src_path, new_dst_path, data.copy())
+            render(new_src_path, new_dst_path, data.copy(), loaders.copy())
         else:
             try:
                 template = env.get_template(filename)
